<?php
/**
 * Plugin Name: TruAnon Identity
 * Plugin URI: https://truanon.com/get
 * Description:  A simple profile badge to let members visibly back their own claim of identity
 * Version: 1.5.1
 * Author: TruAnon
 * Author URI: https://truanon.com/get
 * Text Domain: truanon-verification
 * Domain Path: languages
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Define Constants
 */
if( !defined( 'TRUANON_VERIFICATION_VERSION' ) ) {
	define( 'TRUANON_VERIFICATION_VERSION', '1.1' ); //version of plugin
}
if( !defined( 'TRUANON_VERIFICATION_DIR' ) ) {
	define( 'TRUANON_VERIFICATION_DIR', dirname( __FILE__ ) ); // plugin dir
}
if( !defined( 'TRUANON_VERIFICATION_PUBLIC' ) ) {
	define( 'TRUANON_VERIFICATION_PUBLIC', TRUANON_VERIFICATION_DIR . '/includes/public' ); // plugin admin dir
}
if( !defined( 'TRUANON_VERIFICATION_LEVEL' ) ) { //check if variable is not defined previous then define its
	define( 'TRUANON_VERIFICATION_LEVEL','administrator' ); //this is capability in plugin
}
if( !defined( 'TRUANON_VERIFICATION_ADMIN' ) ) {
	define( 'TRUANON_VERIFICATION_ADMIN', TRUANON_VERIFICATION_DIR . '/includes/admin' ); // plugin admin dir
}
if( !defined( 'TRUANON_VERIFICATION_URL' ) ) {
	define( 'TRUANON_VERIFICATION_URL', plugin_dir_url( __FILE__ ) ); // plugin url
}
if ( !defined( 'TRUANON_VERIFICATION_OPTION') ) {
    define( 'TRUANON_VERIFICATION_OPTION', 'truanon_verification_options' ); // Option Name
}
if ( !defined( 'TRUANON_VERIFICATION_SANDBOX_URL') ) {
    define( 'TRUANON_VERIFICATION_SANDBOX_URL', 'https://staging.truanon.com' ); // Sandbox URL
}
if ( !defined( 'TRUANON_VERIFICATION_LIVE_URL') ) {
    define( 'TRUANON_VERIFICATION_LIVE_URL', 'https://truanon.com' ); // Live URL
}
/**
 * Plugin Activation hook
 * 
 * This hook will call when plugin will activate
 */
global $ww_truanon_verification_public, $ww_truanon_verification_script, $ww_truanon_verification_admin, $ww_truanon_verification_model;

// Model file to handle database queries 
require_once( TRUANON_VERIFICATION_DIR . '/includes/class-truanon-verification-model.php');
$ww_truanon_verification_model = new TruAnon_Verification_Model();

// Script file for CSS and Js 
require_once( TRUANON_VERIFICATION_DIR . '/includes/class-truanon-verification-scripts.php');
$ww_truanon_verification_script = new TruAnon_Verification_Script();
$ww_truanon_verification_script->add_hooks();

// Public file 
require_once( TRUANON_VERIFICATION_DIR . '/includes/class-truanon-verification-public.php');
$ww_truanon_verification_public = new TruAnon_Verification_Public();
$ww_truanon_verification_public->add_hooks();

// Admin file 
require_once( TRUANON_VERIFICATION_ADMIN . '/class-truanon-verification-admin.php');
$ww_truanon_verification_admin = new TruAnon_Verification_Admin();
$ww_truanon_verification_admin->add_hooks();

/**
 * Plugin Activation Hook
 */
register_activation_hook( __FILE__, 'truanon_verification_register_activation' );

function truanon_verification_register_activation() {
    
    global $ww_truanon_verification_model;
    $truanon_db_version = get_option( 'truanon_db_version' );
    if( empty( $truanon_db_version ) ) {
        // Set default data
        $truanon_default_options = array();
        $truanon_default_options['verify_text'] = 'Confirm';
        $truanon_default_options['badge1_1_type'] = 'Custom Image';
		$truanon_default_options['badge1_2_type'] = 'Custom Image';
        $truanon_default_options['badge2_type'] = 'Custom Image';
        $truanon_default_options['not_verify_type'] = 'Custom Image';
        $truanon_default_options['not_verify_text'] = 'Not Confirm';
        $truanon_default_options['badge_less_then_score'] = '2.5';
        $truanon_default_options['badge_greater_then_score'] = '2.5';
        $truanon_default_options['service_id'] = '';
        $truanon_default_options['badge1_description'] = '<div style="text-align:center">
   <div style="font-size:larger">
      <strong>{profile_name}</strong>
      <div> {rank_score} of 5 </div>
      <div style="font-size:smaller;font-weight:300">
         ({rank_title})
      </div>
   </div>
</div>
<BR>
<div style="font-weight:600">
   This member badge has been confirmed using TruAnon.
   You can review their public identity profile <strong><a target="_blank" href="https://truanon.com/p/{profile_url}"> here</a>.</strong>
</div>';

        $truanon_default_options['badge2_description'] = '
<div style="text-align:center">
   <div style="font-size:larger">
      <strong>Unknown</strong>
   </div>
</div>
<BR>
<div style="font-weight:600">
   This badge has not yet been confirmed by the owner.
</div>
';
        $truanon_default_options['not_confirm_txt'] = '
<div style="text-align:center">
   <div style="font-size:larger">
      <strong>Confirm Your Badge</strong>
   </div>
</div>
<BR>
<div style="font-weight:600">
   You must confirm ownership of your profile  badge, 
   {confirm_url}.
</div>';

        $ww_truanon_verification_model->update_all_option_data( $truanon_default_options );

        // update db version 
        update_option( 'truanon_db_version', '1.0.1' );
    }
}